# Advance_Password_Generator
It will generate random passwords of maximum length 12, avoiding names present in specified files.

# Installation
1-  Install package

`pip install passwgeneration`


2- For updated version
 
`pip install --upgrade passwgeneration`         


3-Import package

`import passwgeneration as p`

4- Generate password

`p.generate_password()`
